==> humhub-1.4.2.tar.gz: humhub-1.4.2/protected/humhub/modules/installer/messages/es/base.php <==
<?php
return array (
  '<strong>Admin</strong> Account' => 'Cuenta de <strong>administrador</strong>',
  '<strong>Configuration</strong>' => '<strong>Configuración</strong>',
  '<strong>Congratulations</strong>. You\'re done.' => '<strong>¡Felicidades!</strong>. Ya has acabado.',
  '<strong>Database</strong> Configuration' => 'Configuración de la <strong>base de datos</strong>',
  '<strong>Example</strong> contents' => 'Contenidos de <strong>ejemplo</strong>',
  '<strong>System</strong> Check' => 'Comprobar <strong>sistema</strong>',
  '<strong>Welcome</strong> to HumHub<br>Your Social Network Toolbox' => '<strong>Bienvenido</strong> a HumHub<br />',
  'Allow access for non-registered users to public content (guest access)' => 'Permitir el acceso de usuarios no registrados a contenido público (acceso de invitados)',
  'Allow friendships between members' => 'Permitir solicitudes de amistad entre miembros',
  'Below you have to enter your database connection details. If you’re not sure about these, please contact your system administrator.' => 'Debajo tendrás que escribir la configuración de la base de datos. Si no estás seguro de ello, por favor, contacta con el administrador del sistema.',
  'Calvin Klein – Between love and madness lies obsession.' => '',
  'Check again' => 'Comprobar otra vez',
  'Congratulations! Everything is ok and ready to start over!' => '¡Felicidades! ¡Todo está correcto y listo para empezar!',
  'Create Admin Account' => 'Crear cuenta de administrador',
  'Downloading & Installing Modules...' => 'Descargando e instalando módulos...',
  'External users can register (show registration form on login)' => 'Los usuarios externos pueden registrarse (mostrar el formulario de registro en la página de login)',
  'Here you can decide how new, unregistered users can access HumHub.' => 'Aquí puedes decidir cómo los nuevos usuarios, no registrados, pueden acceder a HumHub',
  'Hostname' => 'Nombre de servidor',
  'Hostname of your MySQL Database Server (e.g. localhost if MySQL is running on the same machine)' => 'Servidor de la base de datos (ej. localhost si MySQL está corriendo en la misma máquina)',
  'HumHub is very flexible and can be adjusted and/or expanded for various different applications thanks to its’ different modules.  The following modules are just a few examples and the ones we thought are most important for your chosen application.<br><br>You can always install or remove modules later. You can find more available modules after installation in the admin area.' => 'HumHub es muy flexible y puede ajustarse o expandirse para diferentes usos gracias a sus diferentes módulos. Los siguientes módulos son sólo unos pocos ejemplos que pensamos que son los más importantes para tu aplicación.<br /><br />Puedes instalar o eliminar módulos más tarde. También puedes encontrar más módulos disponibles en el área de administración',
  'I want to use HumHub for:' => 'Quiero utilizar HumHub para:',
  'Initializing database...' => 'Inicializando base de datos...',
  'My club' => 'Mi club',
  'My community' => 'Mi comunidad',
  'My company (Social Intranet / Project management)' => 'Mi empresa (intranet social / gestión de proyectos)',
  'My educational institution (school, university)' => 'Una institución docente (colegio, universidad)',
  'Name of Database' => 'Nombre de la base de datos',
  'Name of your network' => 'Nombre de tu red social',
  'Newly registered users have to be activated by an admin first' => 'Los nuevos usuarios deben ser antes activados por el administrador',
  'Next' => 'Siguiente',
  'Nike – Just buy it. ;Wink;' => '',
  'Of course, your new social network needs a name. Please change the default name with one you like. (For example the name of your company, organization or club)' => 'Como ya sabrás, tu nueva red social necesita un nombre. Por favor, cambia el nombre por defecto por el que tú quieras. (Por ejemplo, el nombre de tu compañía, organización o club)',
  'Ohh, something went wrong!' => '¡Algo fue mal!',
  'Password' => 'Contraseña',
  'Recommended <strong>Modules</strong>' => '<strong>Módulos</strong> recomendados',
  'Registered members can invite new users via email' => 'Los miembros registrados pueden invitar a usuarios nuevos mediante correo electrónico',
  'Security <strong>Settings</strong>' => '<strong>Configuración</strong> de seguridad',
  'Set up example content (recommended)' => 'Contenido de ejemplo (recomendado)',
  'Sign in' => 'Iniciar sesión',
  'Skip this step, I want to set up everything manually' => 'Saltar este paso. Prefiero configurarlo todo manualmente',
  'Social Network <strong>Name</strong>' => '<strong>Nombre<strong> de la red social</strong></strong>',
  'The installation completed successfully! Have fun with your new social network.' => '¡La instalación se ha completado correctamente!. Diviértete con tu nueva red social.',
  'The name of the database you want to run HumHub in.' => 'El nombre de la base de datos donde quieres que funcione HumHub.',
  'This overview shows all system requirements of HumHub.' => 'Este resumen te mostrará todos los requisitos del sistema para que funcione HumHub.',
  'This wizard will install and configure your own HumHub instance.<br><br>To continue, click Next.' => 'Este asistente instalará y configurará HumHub.<br /><br />Para continuar, haz click en Siguiente.',
  'To avoid a blank dashboard after your initial login, HumHub can install example contents for you. Those will give you a nice general view of how HumHub works. You can always delete the individual contents.' => 'Para evitar tener un tablero de control vacío cuando entres en el sistema, HumHub puede instalar contenidos de ejemplo. Te proporcionan una visión general de cómo funciona HumHub. Luego puedes borrar contenidos individuales.',
  'To simplify the configuration, we have predefined setups for the most common use cases with different options for modules and settings. You can adjust them during the next step.' => 'Para hacer más sencilla la configuración, hemos predefinido algunos casos comunes de uso con diferentes opciones de módulos y configuración. En el siguiente paso podrás configurarlos.',
  'Username' => 'Nombre de usuario',
  'We\'re looking for great slogans of famous brands. Maybe you can come up with some samples?' => 'Estamos buscando grandes eslóganes de marcas famosas. ¿Puedes darnos algún ejemplo?',
  'Welcome Space' => 'Espacio de Bienvenida',
  'Yay! I\'ve just installed HumHub ;Cool;' => '¡Yuju! Acabo de instalar HumHub; ¡Mola!',
  'You\'re almost done. In this step you have to fill out the form to create an admin account. With this account you can manage the whole network.' => 'Casi has terminado. En este paso tienes que rellenar el formulario para crear una cuenta de administrador. Con esta cuenta podrás gestionar todo el sistema.',
  'Your MySQL password.' => 'Tu contraseña MySQL',
  'Your MySQL username' => 'Tu nombre de usuario MySQL',
  'Your first sample space to discover the platform.' => 'Tu primer espacio para descubrir la plataforma.',
);

==> humhub-1.8.1.tar.gz: humhub-1.8.1/protected/humhub/modules/installer/messages/es/base.php <==
<?php
return array (
  '<strong>Admin</strong> Account' => 'Cuenta de <strong>administrador</strong>',
  '<strong>Configuration</strong>' => '<strong>Configuración</strong>',
  '<strong>Congratulations</strong>. You\'re done.' => '<strong>¡Felicidades!</strong>. Ya has acabado.',
  '<strong>Database</strong> Configuration' => 'Configuración de la <strong>base de datos</strong>',
  '<strong>Example</strong> contents' => 'Contenidos de <strong>ejemplo</strong>',
  '<strong>System</strong> Check' => 'Comprobar <strong>sistema</strong>',
  '<strong>Welcome</strong> to HumHub<br>Your Social Network Toolbox' => '<strong>Bienvenido</strong> a HumHub<br />',
  'Allow access for non-registered users to public content (guest access)' => 'Permitir el acceso de usuarios no registrados a contenido público (acceso de invitados)',
  'Allow friendships between members' => 'Permitir solicitudes de amistad entre miembros',
  'Below you have to enter your database connection details. If you’re not sure about these, please contact your system administrator.' => 'Debajo tendrás que escribir la configuración de la base de datos. Si no estás seguro de ello, por favor, contacta con el administrador del sistema.',
  'Calvin Klein – Between love and madness lies obsession.' => 'Calvin Klein - Entre el amor y la locura se encuentra la obsesión.',
  'Check again' => 'Comprobar otra vez',
  'Congratulations! Everything is ok and ready to start over!' => '¡Felicidades! ¡Todo está correcto y listo para empezar!',
  'Create Admin Account' => 'Crear cuenta de administrador',
  'Downloading & Installing Modules...' => 'Descargando e instalando módulos...',
  'External users can register (show registration form on login)' => 'Los usuarios externos pueden registrarse (mostrar el formulario de registro en la página de login)',
  'Here you can decide how new, unregistered users can access HumHub.' => 'Aquí puedes decidir cómo los nuevos usuarios, no registrados, pueden acceder a HumHub',
  'Hostname' => 'Nombre de servidor',
  'Hostname of your MySQL Database Server (e.g. localhost if MySQL is running on the same machine)' => 'Servidor de la base de datos (ej. localhost si MySQL está corriendo en la misma máquina)',
  'HumHub is very flexible and can be adjusted and/or expanded for various different applications thanks to its’ different modules.  The following modules are just a few examples and the ones we thought are most important for your chosen application.<br><br>You can always install or remove modules later. You can find more available modules after installation in the admin area.' => 'HumHub es muy flexible y puede ajustarse o expandirse para diferentes usos gracias a sus diferentes módulos. Los siguientes módulos son sólo unos pocos ejemplos que pensamos que son los más importantes para tu aplicación.<br /><br />Puedes instalar o eliminar módulos más tarde. También puedes encontrar más módulos disponibles en el área de administración',
  'I want to use HumHub for:' => 'Quiero utilizar HumHub para:',
  'Initializing database...' => 'Inicializando base de datos...',
  'My club' => 'Mi club',
  'My community' => 'Mi comunidad',
  'My company (Social Intranet / Project management)' => 'Mi empresa (intranet social / gestión de proyectos)',
  'My educational institution (school, university)' => 'Una institución docente (colegio, universidad)',
  'Name of Database' => 'Nombre de la base de datos',
  'Name of your network' => 'Nombre de tu red social',
  'Newly registered users have to be activated by an admin first' => 'Los nuevos usuarios deben ser antes activados por el administrador',
  'Next' => 'Siguiente',
  'Nike – Just buy it. :wink:' => 'Nike: solo cómpralo. :wink:',
  'Of course, your new social network needs a name. Please change the default name with one you like. (For example the name of your company, organization or club)' => 'Como ya sabrás, tu nueva red social necesita un nombre. Por favor, cambia el nombre por defecto por el que tú quieras. (Por ejemplo, el nombre de tu compañía, organización o club)',
  'Ohh, something went wrong!' => '¡Algo fue mal!',
  'Password' => 'Contraseña',
  'Recommended <strong>Modules</strong>' => '<strong>Módulos</strong> recomendados',
  'Registered members can invite new users via email' => 'Los miembros registrados pueden invitar a usuarios nuevos mediante correo electrónico',
  'Security <strong>Settings</strong>' => '<strong>Configuración</strong> de seguridad',
  'Set up example content (recommended)' => 'Contenido de ejemplo (recomendado)',
  'Sign in' => 'Iniciar sesión',
  'Skip this step, I want to set up everything manually' => 'Saltar este paso. Prefiero configurarlo todo manualmente',
  'Social Network <strong>Name</strong>' => '<strong>Nombre<strong> de la red social</strong></strong>',
  'The installation completed successfully! Have fun with your new social network.' => '¡La instalación se ha completado correctamente!. Diviértete con tu nueva red social.',
  'The name of the database you want to run HumHub in.' => 'El nombre de la base de datos donde quieres que funcione HumHub.',
  'This overview shows all system requirements of HumHub.' => 'Este resumen te mostrará todos los requisitos del sistema para que funcione HumHub.',
  'This wizard will install and configure your own HumHub instance.<br><br>To continue, click Next.' => 'Este asistente instalará y configurará HumHub.<br /><br />Para continuar, haz click en Siguiente.',
  'To avoid a blank dashboard after your initial login, HumHub can install example contents for you. Those will give you a nice general view of how HumHub works. You can always delete the individual contents.' => 'Para evitar tener un tablero de control vacío cuando entres en el sistema, HumHub puede instalar contenidos de ejemplo. Te proporcionan una visión general de cómo funciona HumHub. Luego puedes borrar contenidos individuales.',
  'To simplify the configuration, we have predefined setups for the most common use cases with different options for modules and settings. You can adjust them during the next step.' => 'Para hacer más sencilla la configuración, hemos predefinido algunos casos comunes de uso con diferentes opciones de módulos y configuración. En el siguiente paso podrás configurarlos.',
  'Username' => 'Nombre de usuario',
  'We\'re looking for great slogans of famous brands. Maybe you can come up with some samples?' => 'Estamos buscando grandes eslóganes de marcas famosas. ¿Puedes darnos algún ejemplo?',
  'Welcome Space' => 'Espacio de Bienvenida',
  'Yay! I\'ve just installed HumHub :sunglasses:' => '¡Yuju! Acabo de instalar HumHub; ¡Mola!',
  'You\'re almost done. In this step you have to fill out the form to create an admin account. With this account you can manage the whole network.' => 'Casi has terminado. En este paso tienes que rellenar el formulario para crear una cuenta de administrador. Con esta cuenta podrás gestionar todo el sistema.',
  'Your MySQL password.' => 'Tu contraseña MySQL',
  'Your MySQL username' => 'Tu nombre de usuario MySQL',
  'Your first sample space to discover the platform.' => 'Tu primer espacio para descubrir la plataforma.',
);
